==> alg-alg-2.22.3-20201105.130519-2-sources.jar: cn/com/duiba/nezha/alg/alg/vo/advert/AdBidInputDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.advert;

import lombok.Data;

@Data
public class AdBidInputDo {


    String key;//


    /**
     * 基础信息
     */
    Long newTradeTagId;//行业

    Long advertId;//计划ID

    Long packageId;//配置ID

    Long materialId;//素材ID


    Long appId;//媒体ID

    Long slotId;//广告位ID


    /**
     * 计费 &目标类型
     */
    Integer chargeType; //是否ocpc，1：cpc、2：ocpc

    Integer cvrType;//ocpx 转化目标类型，目前支持：0、2、3（2020.09.10）

    Integer deepCvrType;//ocpx 深度转化目标类型，目前支持：8（2020.09.10）

    /**
     * 定向类型
     */

    Integer targeType; //人工定向、自动定向


    /**
     * 出价
     */

    Long fee;//cpc广告出价

    Long aFee;//ocpx 广告 转化目标出价（配置的）

    Long appAFee;//ocpx 广告 媒体 转化目标出价（******   新增 !!!! *******）


    /**
     * 预估值
     */
    Double preCtr;// 预估ctr

    Double preCvr;// 预估cvr

    Double preDcvr;// 预估dcvr

    Double ctr;// 融合ctr

    Double cvr;// 融合cvr

    Double dcvr;// 融合dcvr


    /**
     * 底价调节
     */
    Long reserveFee;//底价

    Boolean reservePriceWhite;//底价生效白名单，白名单内不触发

    /**
     * 策略因子,影响出价
     */

    Double  specialAccountWeight;// 系统，特殊广告主调价权重，影响出价

    /**
     * 策略因子,影响排序（本接口不需要）
     */
//
//    Double  specialAdvertWeight;// 系统，特殊广告计划调价权重，影响排序
//
//    Double  discountWeight;// 系统，折扣权重，影响排序
//
//    Double  supportWeight;// 算法，扶持调价权重，影响排序
//

    /**
     * 流量标识
     */

    Boolean isDeepControl;// 是否开启双出价
    Integer deepControlTestId;// 双出价 AB分流 测试Id（1：、2：...）


    /**
     * 自动定向流量
     */

    Boolean isAutoTarget;// 是否自动定向流量

}

==> alg-alg-2.22.11-sources.jar: cn/com/duiba/nezha/alg/alg/vo/advert/AdBidInputDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.advert;

import lombok.Data;

@Data
public class AdBidInputDo {


    String key;//


    /**
     * 基础信息
     */
    Long newTradeTagId;//行业

    Long advertId;//计划ID

    Long packageId;//配置ID

    Long materialId;//素材ID


    Long appId;//媒体ID

    Long slotId;//广告位ID


    /**
     * 计费 &目标类型
     */
    Integer chargeType; //是否ocpc，1：cpc、2：ocpc

    Integer cvrType;//ocpx 转化目标类型，目前支持：0、2、3（2020.09.10）

    Integer deepCvrType;//ocpx 深度转化目标类型，目前支持：8（2020.09.10）

    /**
     * 定向类型
     */

    Integer targeType; //人工定向、自动定向

    /**
     * 出价
     */

    Long fee;//cpc广告出价

    Long aFee;//ocpx 广告 转化目标出价（配置的）

    Long appAFee;//ocpx 广告 媒体 转化目标出价（******   新增 !!!! *******）

    Long deepFee;//深度目标成本（2020.11.12）

    /**
     * 预估值
     */
    Double preCtr;// 预估ctr

    Double preCvr;// 预估cvr

    Double preDcvr;// 预估dcvr

    Double ctr;// 融合ctr

    Double cvr;// 融合cvr

    Double dcvr;// 融合dcvr


    /**
     * 底价调节
     */
    Long reserveFee;//底价

    Boolean reservePriceWhite;//底价生效白名单，白名单内不触发

    /**
     * 策略因子,影响出价
     */

    Double specialAccountWeight;// 系统，特殊广告主调价权重，影响出价

    /**
     * 策略因子,影响排序（本接口不需要）
     */
//
//    Double  specialAdvertWeight;// 系统，特殊广告计划调价权重，影响排序
//
//    Double  discountWeight;// 系统，折扣权重，影响排序
//
//    Double  supportWeight;// 算法，扶持调价权重，影响排序
//


    /**
     * 自动定向流量标识
     */

    Boolean isAutoTarget;// 是否自动定向流量





    /**
     * 分流表识
     */
    Integer abTestId;// 竞价策略，AB分流 测试Id（1：默认组、2：实验组...）


    Integer deepControlType;// 双出价模式： null：无  1：设定深度目标成本，分广告位设置目标成本 2：分流量出价，保前端成本  （2020.11.12 改）

    Integer bidControlType;// 竞价策略，1：常规；2：跑量模式（2020.11.12）


    /**
     * 探索流量加价
     */

    Double exploreFactor;//

}
